summaryrefslogtreecommitdiffstats
path: root/keyboards/primekb/prime_o/keymaps/reasonsandreasons/keymap.c
diff options
context:
space:
mode:
authorlokher <lokher@gmail.com>2022-09-13 11:13:00 +0800
committerlokher <lokher@gmail.com>2022-09-13 11:13:00 +0800
commitfe13cedf8c09fa34d5cec4e4c624738095176625 (patch)
tree818436626d49c7f22f325632b2053edba10d4358 /keyboards/primekb/prime_o/keymaps/reasonsandreasons/keymap.c
parentfa207545a9759c50b9f230eb608d86a9085801d4 (diff)
parentf46379f308783994b8178f95adc686f4b4c3ebd8 (diff)
merge upstream master
Diffstat (limited to 'keyboards/primekb/prime_o/keymaps/reasonsandreasons/keymap.c')
-rw-r--r--keyboards/primekb/prime_o/keymaps/reasonsandreasons/keymap.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/keyboards/primekb/prime_o/keymaps/reasonsandreasons/keymap.c b/keyboards/primekb/prime_o/keymaps/reasonsandreasons/keymap.c
index 2a320aecf2..e8ca64c908 100644
--- a/keyboards/primekb/prime_o/keymaps/reasonsandreasons/keymap.c
+++ b/keyboards/primekb/prime_o/keymaps/reasonsandreasons/keymap.c
@@ -130,7 +130,7 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
* | | PgUp | Home | Up | End | | | Vol- | Vol+ | Mute | | | | | | |
* | | | | | | | | | | | | | | | | |
* |------+------|------+------+------+------+------+------+------+------+------+------+------+------+------+------|
* | | PgDn | Left | Down |Right | | | Play | Prev | Next | | | | | | RESET|
* | | | | | | | | | | | | | | | | |
* |------+------|------+------+------+------+------+------+------+------+------+------+------+------+------+------|
* | | | | | | | | | | | | | | | | |
@@ -144,7 +144,7 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
[3] = LAYOUT(
_______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______,
_______, KC_PGUP, KC_HOME, KC_UP, KC_END, _______, _______, KC__VOLDOWN, KC__VOLUP, KC__MUTE, _______, _______, _______, _______, _______, _______,
- _______, KC_PGDN, KC_LEFT, KC_DOWN, KC_RGHT, _______, _______, KC_MPLY, KC_MRWD, KC_MFFD, _______, _______, _______, _______, _______, RESET,
+ _______, KC_PGDN, KC_LEFT, KC_DOWN, KC_RGHT, _______, _______, KC_MPLY, KC_MRWD, KC_MFFD, _______, _______, _______, _______, _______, QK_BOOT,
_______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, BL_TOGG,
DF(1), _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, BL_STEP, BL_TOGG
),
@@ -130,7 +130,7 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
* | | | | | | | | | | | | | | | | |
* |------+------|------+------+------+------+------+------+------+------+------+------+------+------+------+------|
- * | | PgDn | Left | Down |Right | | | Play | Prev | Next | | | | | | RESET|
+ * | | PgDn | Left | Down |Right | | | Play | Prev | Next | | | | | | QK_BOOT|
* | | | | | | | | | | | | | | | | |
* |------+------|------+------+------+------+------+------+------+------+------+------+------+------+------+------|